@@ -88,10 +88,11 @@ int csnappy_decompress_noheader(
 		if (likely((opcode & 3) == 0)) {
 			if (unlikely(length > 60)) {
 				uint32_t extra_bytes = length - 60;
+				int shift;
 				if (unlikely(src + extra_bytes > src_end))
 					return CSNAPPY_E_DATA_MALFORMED;
 				length = 0;
-				for (int shift = 0, max_shift = extra_bytes*8;
+				for (shift = 0, max_shift = extra_bytes*8;
 					shift < max_shift;
 					shift += 8)
 					length |= *src++ << shift;
